==> tuia-news-center-api-0.0.44-xt4-20180627.033812-1-sources.jar: cn/com/duiba/tuia/news/center/dto/req/EnemyDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaotian on 2018/6/22.
 */
public class EnemyDto implements Serializable{

    private Long id;

    private Long userId;

    private Long enemyId;

    private String enemyName;

    private String enemyHead;

    private Integer enemyStatus;

    private Integer steal;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getEnemyId() {
        return enemyId;
    }

    public void setEnemyId(Long enemyId) {
        this.enemyId = enemyId;
    }

    public String getEnemyName() {
        return enemyName;
    }

    public void setEnemyName(String enemyName) {
        this.enemyName = enemyName == null ? null : enemyName.trim();
    }

    public String getEnemyHead() {
        return enemyHead;
    }

    public void setEnemyHead(String enemyHead) {
        this.enemyHead = enemyHead == null ? null : enemyHead.trim();
    }

    public Integer getEnemyStatus() {
        return enemyStatus;
    }

    public void setEnemyStatus(Integer enemyStatus) {
        this.enemyStatus = enemyStatus;
    }

    public Integer getSteal() {
        return steal;
    }

    public void setSteal(Integer steal) {
        this.steal = steal;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-news-center-api-2.0.0.0-xt-20190403.025840-1-sources.jar: cn/com/duiba/tuia/news/center/dto/req/EnemyDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaotian on 2018/6/22.
 */
public class EnemyDto implements Serializable{

    private Long id;

    private Long userId;

    private Long enemyId;

    private String enemyName;

    private String enemyHead;

    private Integer enemyStatus;

    private Integer steal;

    private Long ripeTime;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getRipeTime() {
        return ripeTime;
    }

    public void setRipeTime(Long ripeTime) {
        this.ripeTime = ripeTime;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getEnemyId() {
        return enemyId;
    }

    public void setEnemyId(Long enemyId) {
        this.enemyId = enemyId;
    }

    public String getEnemyName() {
        return enemyName;
    }

    public void setEnemyName(String enemyName) {
        this.enemyName = enemyName == null ? null : enemyName.trim();
    }

    public String getEnemyHead() {
        return enemyHead;
    }

    public void setEnemyHead(String enemyHead) {
        this.enemyHead = enemyHead == null ? null : enemyHead.trim();
    }

    public Integer getEnemyStatus() {
        return enemyStatus;
    }

    public void setEnemyStatus(Integer enemyStatus) {
        this.enemyStatus = enemyStatus;
    }

    public Integer getSteal() {
        return steal;
    }

    public void setSteal(Integer steal) {
        this.steal = steal;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
